# HCFSStatus

HCFS Endpoint info
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**endpoint** | **str** | Endpoint for accessing | [optional] 
**underlayer_file_system_version** | **str** | Underlayer HCFS Compatible Version | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


